pplpy_doc: Python interface to the Parma Polyhedra Library (documentation)
==========================================================================

Description
-----------

PPL Python wrapper (documentation)

The Python package pplpy provides a wrapper to the C++ Parma Polyhedra
Library (PPL).

The whole package started as a fork of a tiny part of the Sage library.

We are using the compatible fork passagemath-ppl.

License
-------

GPL version 3


Upstream Contact
----------------

-  https://github.com/passagemath/passagemath-ppl
